@@ -116,34 +116,16 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
 
     // ----------------------------------------------------- ReplicatedMapEntry
 
-    /**
-     * Has the object changed since last replication and is not in a locked state
-     *
-     * @return boolean
-     */
     @Override
     public boolean isDirty() {
-        return getDeltaRequest().getSize() > 0;
+        return deltaRequest.getSize() > 0;
     }
 
-    /**
-     * If this returns true, the map will extract the diff using getDiff() Otherwise it will serialize the entire
-     * object.
-     *
-     * @return boolean
-     */
     @Override
     public boolean isDiffable() {
         return true;
     }
 
-    /**
-     * Returns a diff and sets the dirty map to false
-     *
-     * @return a serialized view of the difference
-     *
-     * @throws IOException IO error serializing
-     */
     @Override
     public byte[] getDiff() throws IOException {
         SynchronizedStack<DeltaRequest> deltaRequestPool = null;
@@ -183,33 +165,21 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
         return null;
     }
 
-    /**
-     * Applies a diff to an existing object.
-     *
-     * @param diff   Serialized diff data
-     * @param offset Array offset
-     * @param length Array length
-     *
-     * @throws IOException IO error deserializing
-     */
     @Override
     public void applyDiff(byte[] diff, int offset, int length) throws IOException, ClassNotFoundException {
+        Thread currentThread = Thread.currentThread();
+        ClassLoader contextLoader = currentThread.getContextClassLoader();
         lockInternal();
         try (ObjectInputStream stream = ((ClusterManager) getManager()).getReplicationStream(diff, offset, length)) {
-            Thread currentThread = Thread.currentThread();
-            ClassLoader contextLoader = currentThread.getContextClassLoader();
-            try {
-                ClassLoader[] loaders = getClassLoaders();
-                if (loaders != null && loaders.length > 0) {
-                    currentThread.setContextClassLoader(loaders[0]);
-                }
-                getDeltaRequest().readExternal(stream);
-                getDeltaRequest().execute(this, ((ClusterManager) getManager()).isNotifyListenersOnReplication());
-            } finally {
-                currentThread.setContextClassLoader(contextLoader);
+            ClassLoader[] loaders = getClassLoaders();
+            if (loaders != null && loaders.length > 0) {
+                currentThread.setContextClassLoader(loaders[0]);
             }
+            deltaRequest.readExternal(stream);
+            deltaRequest.execute(this, ((ClusterManager) getManager()).isNotifyListenersOnReplication());
         } finally {
             unlockInternal();
+            currentThread.setContextClassLoader(contextLoader);
         }
     }
 
@@ -270,11 +240,6 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
         }
     }
 
-    /**
-     * If this returns true, to replicate that an object has been accessed
-     *
-     * @return boolean
-     */
     @Override
     public boolean isAccessReplicate() {
         long replDelta = System.currentTimeMillis() - getLastTimeReplicated();
@@ -284,9 +249,6 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
         return false;
     }
 
-    /**
-     * Access to an existing object.
-     */
     @Override
     public void accessEntry() {
         this.access();
@@ -296,28 +258,17 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
 
     // ----------------------------------------------------- Session Properties
 
-    /**
-     * returns true if this session is the primary session, if that is the case, the manager can expire it upon timeout.
-     */
     @Override
     public boolean isPrimarySession() {
         return isPrimarySession;
     }
 
-    /**
-     * Sets whether this is the primary session or not.
-     *
-     * @param primarySession Flag value
-     */
     @Override
     public void setPrimarySession(boolean primarySession) {
         this.isPrimarySession = primarySession;
     }
 
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public void setId(String id, boolean notify) {
         super.setId(id, notify);
@@ -330,11 +281,6 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
     }
 
 
-    /**
-     * Set the session identifier for this session.
-     *
-     * @param id The new session identifier
-     */
     @Override
     public void setId(String id) {
         setId(id, true);
@@ -359,11 +305,6 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
         }
     }
 
-    /**
-     * Set the <code>isNew</code> flag for this session.
-     *
-     * @param isNew The new value for the <code>isNew</code> flag
-     */
     @Override
     public void setNew(boolean isNew) {
         setNew(isNew, true);
@@ -381,13 +322,6 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
         }
     }
 
-    /**
-     * Set the authenticated Principal that is associated with this Session. This provides an <code>Authenticator</code>
-     * with a means to cache a previously authenticated Principal, and avoid potentially expensive
-     * <code>Realm.authenticate()</code> calls on every request.
-     *
-     * @param principal The new Principal, or <code>null</code> if none
-     */
     @Override
     public void setPrincipal(Principal principal) {
         setPrincipal(principal, true);
@@ -405,11 +339,6 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
         }
     }
 
-    /**
-     * Set the authentication type used to authenticate our cached Principal, if any.
-     *
-     * @param authType The new cached authentication type
-     */
     @Override
     public void setAuthType(String authType) {
         setAuthType(authType, true);
@@ -427,9 +356,6 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
         }
     }
 
-    /**
-     * Return the <code>isValid</code> flag for this session.
-     */
     @Override
     public boolean isValid() {
         if (!this.isValid) {
@@ -438,7 +364,7 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
         if (this.expiring) {
             return true;
         }
-        if (ACTIVITY_CHECK && accessCount.get() > 0) {
+        if (activityCheck && accessCount.get() > 0) {
             return true;
         }
         if (maxInactiveInterval > 0) {
@@ -461,9 +387,6 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
         return this.isValid;
     }
 
-    /**
-     * End the access and register to ReplicationValve (crossContext support)
-     */
     @Override
     public void endAccess() {
         super.endAccess();
@@ -474,12 +397,6 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
 
     // ------------------------------------------------- Session Public Methods
 
-    /**
-     * Perform the internal processing required to invalidate this session, without triggering an exception if the
-     * session has already expired.
-     *
-     * @param notify Should we notify listeners about the demise of this session?
-     */
     @Override
     public void expire(boolean notify) {
         expire(notify, true);
@@ -530,9 +447,6 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
         }
     }
 
-    /**
-     * Release all object references, and initialize instance variables, in preparation for reuse of this object.
-     */
     @Override
     public void recycle() {
         lockInternal();
@@ -605,15 +519,6 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
     }
 
 
-    /**
-     * Read a serialized version of the contents of this session object from the specified object input stream, without
-     * requiring that the StandardSession itself have been serialized.
-     *
-     * @param stream The object input stream to read from
-     *
-     * @exception ClassNotFoundException if an unknown class is specified
-     * @exception IOException            if an input/output error occurs
-     */
     @Override
     public void readObjectData(ObjectInputStream stream) throws ClassNotFoundException, IOException {
         doReadObject((ObjectInput) stream);
@@ -623,14 +528,6 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
         doReadObject(stream);
     }
 
-    /**
-     * Write a serialized version of the contents of this session object to the specified object output stream, without
-     * requiring that the StandardSession itself have been serialized.
-     *
-     * @param stream The object output stream to write to
-     *
-     * @exception IOException if an input/output error occurs
-     */
     @Override
     public void writeObjectData(ObjectOutputStream stream) throws IOException {
         writeObjectData((ObjectOutput) stream);
@@ -650,6 +547,12 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
         }
     }
 
+    /**
+     * Get the request.
+     * @return the request
+     * @deprecated Unused. This method will be removed in Tomcat 12.
+     */
+    @Deprecated
     public DeltaRequest getDeltaRequest() {
         return deltaRequest;
     }
@@ -707,18 +610,6 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
 
     // ----------------------------------------------HttpSession Public Methods
 
-    /**
-     * Remove the object bound with the specified name from this session. If the session does not have an object bound
-     * with this name, this method does nothing.
-     * <p>
-     * After this method executes, and if the object implements <code>HttpSessionBindingListener</code>, the container
-     * calls <code>valueUnbound()</code> on the object.
-     *
-     * @param name   Name of the object to remove from this session.
-     * @param notify Should we notify interested listeners that this attribute is being removed?
-     *
-     * @exception IllegalStateException if this method is called on an invalidated session
-     */
     @Override
     public void removeAttribute(String name, boolean notify) {
         removeAttribute(name, notify, true);
@@ -732,20 +623,6 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
         removeAttributeInternal(name, notify, addDeltaRequest);
     }
 
-    /**
-     * Bind an object to this session, using the specified name. If an object of the same name is already bound to this
-     * session, the object is replaced.
-     * <p>
-     * After this method executes, and if the object implements <code>HttpSessionBindingListener</code>, the container
-     * calls <code>valueBound()</code> on the object.
-     *
-     * @param name  Name to which the object is bound, cannot be null
-     * @param value Object to be bound, cannot be null
-     *
-     * @exception IllegalArgumentException if an attempt is made to add a non-serializable object in an environment
-     *                                         marked distributable.
-     * @exception IllegalStateException    if this method is called on an invalidated session
-     */
     @Override
     public void setAttribute(String name, Object value) {
         setAttribute(name, value, true, true);
@@ -781,13 +658,11 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
         removeNote(name, true);
     }
 
-    @SuppressWarnings("deprecation")
     public void removeNote(String name, boolean addDeltaRequest) {
         lockInternal();
         try {
             super.removeNote(name);
-            if (addDeltaRequest && manager instanceof ManagerBase &&
-                    ((ManagerBase) manager).getPersistAuthenticationNotes()) {
+            if (addDeltaRequest) {
                 deltaRequest.removeNote(name);
             }
         } finally {
@@ -801,7 +676,6 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
         setNote(name, value, true);
     }
 
-    @SuppressWarnings("deprecation")
     public void setNote(String name, Object value, boolean addDeltaRequest) {
 
         if (value == null) {
@@ -812,8 +686,7 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
         lockInternal();
         try {
             super.setNote(name, value);
-            if (addDeltaRequest && manager instanceof ManagerBase &&
-                    ((ManagerBase) manager).getPersistAuthenticationNotes()) {
+            if (addDeltaRequest) {
                 deltaRequest.setNote(name, value);
             }
         } finally {
@@ -824,17 +697,6 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
 
     // -------------------------------------------- HttpSession Private Methods
 
-    /**
-     * Read a serialized version of this session object from the specified object input stream.
-     * <p>
-     * <b>IMPLEMENTATION NOTE </b>: The reference to the owning Manager is not restored by this method, and must be set
-     * explicitly.
-     *
-     * @param stream The input stream to read from
-     *
-     * @exception ClassNotFoundException if an unknown class is specified
-     * @exception IOException            if an input/output error occurs
-     */
     @Override
     protected void doReadObject(ObjectInputStream stream) throws ClassNotFoundException, IOException {
         doReadObject((ObjectInput) stream);
@@ -929,7 +791,7 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
     }
 
     @Override
-    public void writeExternal(ObjectOutput out) throws java.io.IOException {
+    public void writeExternal(ObjectOutput out) throws IOException {
         lockInternal();
         try {
             doWriteObject(out);
@@ -939,26 +801,11 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
     }
 
 
-    /**
-     * Write a serialized version of this session object to the specified object output stream.
-     * <p>
-     * <b>IMPLEMENTATION NOTE </b>: The owning Manager will not be stored in the serialized representation of this
-     * Session. After calling <code>readObject()</code>, you must set the associated Manager explicitly.
-     * <p>
-     * <b>IMPLEMENTATION NOTE </b>: Any attribute that is not Serializable will be unbound from the session, with
-     * appropriate actions if it implements HttpSessionBindingListener. If you do not want any such attributes, be sure
-     * the <code>distributable</code> property of the associated Manager is set to <code>true</code>.
-     *
-     * @param stream The output stream to write to
-     *
-     * @exception IOException if an input/output error occurs
-     */
     @Override
     protected void doWriteObject(ObjectOutputStream stream) throws IOException {
         doWriteObject((ObjectOutput) stream);
     }
 
-    @SuppressWarnings("deprecation")
     private void doWriteObject(ObjectOutput stream) throws IOException {
         // Write the scalar instance variables (except Manager)
         stream.writeObject(Long.valueOf(creationTime));
@@ -978,13 +825,11 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
             log.debug(sm.getString("deltaSession.writeSession", id));
         }
 
-        if (manager instanceof ManagerBase && ((ManagerBase) manager).getPersistAuthenticationNotes()) {
-            // Write the notes associated with authentication. Without these,
-            // authentication can fail without sticky sessions or if there is a
-            // fail-over during authentication.
-            stream.writeObject(notes.get(org.apache.catalina.authenticator.Constants.SESSION_ID_NOTE));
-            stream.writeObject(notes.get(org.apache.catalina.authenticator.Constants.FORM_REQUEST_NOTE));
-        }
+        // Write the notes associated with authentication. Without these,
+        // authentication can fail without sticky sessions or if there is a
+        // fail-over during authentication.
+        stream.writeObject(notes.get(org.apache.catalina.authenticator.Constants.SESSION_ID_NOTE));
+        stream.writeObject(notes.get(org.apache.catalina.authenticator.Constants.FORM_REQUEST_NOTE));
 
         // Accumulate the names of serializable and non-serializable attributes
         String keys[] = keys();
@@ -1067,7 +912,7 @@ public class DeltaSession extends StandardSession implements Externalizable, Clu
     }
 
     protected void setAccessCount(int count) {
-        if (accessCount == null && ACTIVITY_CHECK) {
+        if (accessCount == null && activityCheck) {
             accessCount = new AtomicInteger();
         }
         if (accessCount != null) {
