@@ -27,14 +27,14 @@ import java.util.concurrent.Future;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.TimeoutException;
 
-import javax.websocket.ClientEndpoint;
-import javax.websocket.ContainerProvider;
-import javax.websocket.OnError;
-import javax.websocket.OnMessage;
-import javax.websocket.OnOpen;
-import javax.websocket.Session;
-import javax.websocket.WebSocketContainer;
-import javax.websocket.server.ServerEndpointConfig;
+import jakarta.websocket.ClientEndpoint;
+import jakarta.websocket.ContainerProvider;
+import jakarta.websocket.OnError;
+import jakarta.websocket.OnMessage;
+import jakarta.websocket.OnOpen;
+import jakarta.websocket.Session;
+import jakarta.websocket.WebSocketContainer;
+import jakarta.websocket.server.ServerEndpointConfig;
 
 import org.junit.Assert;
 import org.junit.Test;
@@ -51,7 +51,7 @@ import org.apache.tomcat.websocket.WsSession;
 /*
  * https://bz.apache.org/bugzilla/show_bug.cgi?id=66508
  *
- * If the client sends a close while the server is waiting for the client before sending the rest of a message, the
+ * If the client sends a close while the server waiting for the client before sending the rest of a message, the
  * processing of the close from the client can hang until the sending of the message times out.
  *
  * This is packaged in a separate class to allow test specific parameterisation.
@@ -124,9 +124,6 @@ public class TestWsRemoteEndpointImplServerDeadlock extends WebSocketBaseTest {
         // Server buffers are full. Server cannot send any more messages.
         // Server is now blocked waiting for the client to read the messages.
 
-        // Set a short session close timeout (milliseconds)
-        session.getUserProperties().put(
-            org.apache.tomcat.websocket.Constants.SESSION_CLOSE_TIMEOUT_PROPERTY, Long.valueOf(2000));
         // Close the session from the client
         session.close();
 
@@ -170,15 +167,7 @@ public class TestWsRemoteEndpointImplServerDeadlock extends WebSocketBaseTest {
     public static class Bug66508Endpoint {
 
         // 1024k message
-        private static final String MSG;
-        static {
-            final int len = 1024 * 8;
-            StringBuilder sb = new StringBuilder(len);
-            for (int i = 0; i < len; i++) {
-                sb.append('a');
-            }
-            MSG = sb.toString();
-        }
+        private static final String MSG = "a".repeat(1024 * 8);
 
         private static volatile Session serverSession = null;
         private CountDownLatch serverSendLatch = initialServerSendLatch;
